# OpenDR Semantic Segmentation

This folder contains the BiseNet algorithm for semantic segmentation in the OpenDR Toolkit.

## Sources

The algorithm files are copied from [BiseNet](https://github.com/ooooverflow/BiSeNet) with minor modifications.

